#
# spec file for package rednotebook
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rednotebook
Version:        2.33
Release:        1.3
Summary:        Graphical diary and journal
# See note at the end of README: code is using some LGPL-3.0+ module, so the resulting work is GPL-3.0+.
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            http://rednotebook.sourceforge.net/
Source:         https://github.com/jendrikseipp/rednotebook/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3-cairo-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python3-PyYAML
Requires:       python3-gobject-Gdk
Recommends:     %{name}-lang
Recommends:     python3-chardet
Recommends:     python3-pyenchant
BuildArch:      noarch

%description
RedNotebook is a graphical journal to keep track of notes and thoughts.
It includes a calendar navigation, customizable templates, export
functionality and word clouds. You can also format, tag and search your
entries.

%lang_package

%prep
%setup -q

%build

%install
python3 setup.py install --prefix=%{_prefix} --exec-prefix=%{_prefix} --root=%{buildroot}
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name} Calendar
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.svg
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/rednotebook.appdata.xml

%files lang -f %{name}.lang

%changelog
* Thu May  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.33
  * Ignore image filenames and web links in word clouds (#537, #696, @laraconda).
  * Add more pre-commit checks (#705, @laraconda).
- Update to version 2.32
  * Allow copying text in preview mode (#732, Jendrik Seipp).
  * Allow hashtags that start with (but are longer than) hex colors and preprocessor directives (#738, Jendrik Seipp).
  * Highlight hashtags and formatting within lists (#744, Jendrik Seipp).
  * Improve Debian packaging (Phil Wyett).
- Update to version 2.31
  * Add basic text replace functionality (#715, @curioussushiroll).
- Update to version 2.30
  * Modernize code (#689, @HighnessAtharva and @laraconda).
  * Fix: Correctly color URLs with hashtags symbols in edit mode (#703, @laraconda).
  * Add menu item to insert numbered lists (#526, @curioussushiroll).
* Thu May  4 2023 Deepthi Yadabettu Venkatachala <deepthi.venkatachala@suse.com>
- Update to version 2.29.6
  * Restore all keyboard shorts (#690, Jendrik Seipp).
  2.29.5
  * Fix: Don't try to print WebKit2 version on Windows (#686, Jendrik Seipp).
  2.29.4
  * Accept arbitrary WebKit2 version. Use 4.1 if available (#681, Jendrik Seipp).
  2.29.3
  * Make all menu items translatable (Jendrik Seipp).
  * Packaging: install translation files under /share/locale again (#666, Jendrik Seipp).
  2.29
  * Document alternatives for changing the GTK theme on Windows (Ankur A Sharma, #494).
  * Fix en_GB translations (Jendrik Seipp, #659).
  2.28.1
  * Require setuptools for Debian package (Jendrik Seipp).
  2.28
  * Remove code that uses the deprecated distutils module (Jendrik Seipp, #655, #656).
  * Fix checking for newer versions (Jendrik Seipp).
  * Gracefully handle unsupported locale settings (Jendrik Seipp, #613).
  2.27.2
  * Fix passing command line arguments (Jendrik Seipp).
  * Update translation files (Jendrik Seipp).
  2.27
  * Upgrade to GTK 3.24 on Windows (Jendrik Seipp).
  * Use external preview on Windows since embedding the preview is
    impossible with newer GTK versions (Jendrik Seipp).
  * Use GtkApplication class and only allow running one RedNotebook instance
    at a time (Jendrik Seipp).
  * Add support for GtkSourceView 4 (Jendrik Seipp).
  * Raise minimum Python version to 3.6 (Jendrik Seipp).
  * Add more languages to Windows installer (Jendrik Seipp).
  2.26
  * Fix issue #632 by skipping obsolete Python function (Jendrik Seipp).
  * Fix: only try to load CEF Python on Windows (Jendrik Seipp).
  * Update Turkish translation (sabriunal).
  2.25
  * Use icon names instead of GTK stock icons to support newer GTK versions (Jendrik Seipp).
  * Handle several GTK deprecation warnings (Jendrik Seipp).
  2.24
  * Revert to plain naming scheme for data files since reverse DNS naming causes
    problems (#611, Phil Wyett).
  2.23
  * Check that a newly written month file is valid before deleting the old month file.
  * Rename "autostart" file. Please reenable autostart option in preferences if you
    want RedNotebook to run on system startup.
  * Fix Python crash on program start (#583, Max Krummenacher).
  * Prevent save failures on network and cloud drives (#593, Robert Little).
  * Add script for importing entries (#571, Cary Gravel).
  * Revamp packaging for Debian (#599, #600, Phil Wyett).
  * Fix continuous integration tests.
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.22
  * Add a "Give Feedback" button
* Thu Feb 11 2021 Dirk Müller <dmueller@suse.com>
- update to 2.21:
  * Update MathJax to version 3 (#515, @dgcampea).
  * Fix date references in CEF-based HtmlView (#544, Paweł Żukowski).
  * Fix drag and drop (#492, @dgcampea).
  * Fix external previews (Eric Chazan).
  * Document how to change the theme on Windows (#487, Ankur A. Sharma).
  * Allow symlinking to `./run` script (#509).
  * Reload GTK theme colors when saving the journal (#485).
  * Don't use dark mode for exported HTML files (#486).
  * Use PNG version instead of SVG for RedNotebook icons to avoid problems on macOS.
  * Use GitHub actions for continuous integration testing.
  * Use background and foreground colors from GTK theme for HTML preview.
  * Fix HTML colors for dark themes (#474).
* Fri Jan 24 2020 max.oss.09@gmail.com
- update to 2.16
  + Add menu items for adding titles (#464, Paweł Żukowski).
  + Upgrade msgfmt.py to version 1.2 (#470).
* Wed Jan  1 2020 max.oss.09@gmail.com
- update to 2.15
  + Fix tray icon on Windows (#394).
  2.14 (2019-11-17)
  + Support entry reference links in exported HTML (#452, Paweł Żukowski).
  + Add support for dark themes to cloud panel (#438).
  2.13 (2019-11-07)
  + Change unnamed date references from 2019-11-06 to [2019-11-06] (#458, #460, Paweł Żukowski).
  + Add option for controlling number of displayed tags (#456, Paweł Żukowski).
  + Fix setting maximum number of displayed tags (#461).
  2.12 (2019-11-02)
  + Allow linking between days with dates like 2019-02-14 and `[named links 2019-02-14]` (#176, #444, Paweł Żukowski).
  + Allow opening statistics dialog multiple times in one session (#370, #457, Paweł Żukowski).
  + Warn about outdated backups every week by default.
  + Increase default width of left panel to ensure that the calendar is fully visible (#376).
  2.11.1 (2019-04-07)
  + Always initialize spell checking whenever we switch text buffers (fixes #435).
  2.11 (2019-03-26)
  + Revert to GTK 3.18 stack on Windows (fixes #429 and #430).
  2.10 (2019-03-24)
  + Automatically push newest version to flathub.
  2.9.1 (2019-03-20)
  + Disable internal preview on Windows again since it sometimes crashes the app.
  2.9 (2019-03-17)
  + Use Python 3.6 and GTK 3.22 on Windows.
  + Build Windows installer with Appveyor.
  2.8.1 (2019-03-17)
  + Load the correct template for a given weekday (fixes #416).
  + Clear text buffers when opening a new journal (fixes #421).
  + Minor bug fixes.
  2.8 (2018-11-15)
  + Support internal previews on Windows again (#369).
  2.7.1 (2018-11-13)
  + Never let search phrases end up in the main text field (fixes #401).
  + Fix spell checking (fixes #412).
  2.7 (2018-11-06)
  + Use GtkSourceView for editor to obtain better undo/redo functionality (thanks @takluyver).
  + When saving, update the list of tags in the auto-complete list for the search.
  + Fix opening RedNotebook homepage from About dialog (#411).
  2.6.1 (2018-08-21)
  + Fix bug preventing new installations from starting up.
  2.6 (2018-08-20)
  + Move date format option to preferences dialog.
  + Use date format option for date in titlebar.
  + Remember selected date format for exports between sessions.
  + Check remote info.py file for latest version number.
  + Check for latest version in separate thread.
  2.5 (2018-06-08)
  + Restore instant search (search as you type).
  + Add option for disabling instant search to preferences dialog.
  + Disable undo/redo buttons in preview mode (fixes #103).
  + Remove option to show/hide right-side tags panel from GUI (still present in configuration file).
  2.4 (2018-03-07)
  + Make search significantly faster by indexing all days.
  + Allow searching for multiple words.
  + Add AppVersion to InnoSetup file.
  + Homepage: Switch to HTTPS.
* Sat Sep 30 2017 zaitor@opensuse.org
- Update to version 2.3:
  + Compress backups.
  + Use newer txt2tags version 2.6 and reapply changes to obtain a
    GPL-2+ version.
  + Remove brittle PDF export. Please export to HTML and print to
    PDF with browser instead.
  + Remove intro page from export wizard.
  + Fix: image files were not found on Windows and Mac OS.
  + Print peak memory usage on Linux when program exits.
  + Hide tags panel completely by default instead of only
    minimizing it.
  + Update Debian files.
* Sat Sep 16 2017 luc14n0@linuxmail.org
- Update to version 2.2:
  + Port RedNotebook 2 to Windows.
  + Windows: uninstall old version before installing new version to
    remove old files.
  + Windows: use Aspell for spell checking.
  + Update Debian files.
- Changes from version 2.1:
  + Make webkit optional (but highly recommended). If missing, show
    preview in external browser.
  + Support inserting SVG images.
  + Don't switch between edit and review mode automatically by
    default.
- Changes from version 2.1.1:
  + Reset package name to 'rednotebook'.
- Changes from version 2.1.2:
  + Fix "Exec" field in .desktop file.
- Changes from version 2.1.3:
  + Fix creating translation files.
- Changes from version 2.1.4:
  + Use old names for appdata and desktop files.
- Changes from version 2.1.5:
  + Fix debian/control.
- Drop rednotebook-locale-unicode-fix.patch: Fixed upstream.
- Drop obsolete post(un) handling of following macros:
  desktop_database_post(un) and icon_theme_cache_post(un),
  file-triggers takes care of this for us now.
- Run spec-cleaner, modernize spec.
* Sat Jul 15 2017 zaitor@opensuse.org
- Update to version 2.0:
  + Port to Python 3 and GTK 3.
  + Add index of tags to LaTeX export.
  + Use new CDN link for MathJax.
- Add rednotebook-locale-unicode-fix.patch: Fix runtime crash,
  patches from upstream git.
- Following upstreams porting: Drop python-devel, python-gtk,
  python-webkitgtk, python-gtk, python-webkitgtk, python-PyYAML and
  python-chardet BuildRequires, Requires and Recommends.
- Add hicolor-icon-theme, pkgconfig, python3-cairo-devel,
  python3-gobject-devel and python3-setuptools BuildRequires.
- Add python3-PyYAML and python3-gobject-Gdk Requires,
  python3-chardet and python3-pyenchant Recommends.
- Change python macros to python3 variant.
- Drop obsolete conditionals for no longer supported versions of
  openSUSE.
* Fri Mar  3 2017 zaitor@opensuse.org
- Update to version 1.15:
  + Bundle pygtkspellcheck 4.0.5 since earlier versions contain a
    bug (lp#1615629).
  + Fix toggling autostart (lp#1628497).
  + Set system tray icon name (lp#1660129).
* Thu Mar  2 2017 zaitor@opensuse.org
- Replace python-yaml with python-PyYAML Requires, needed after
  python-singlespec changes.
* Sat Oct  8 2016 zaitor@opensuse.org
- Update to version 1.14:
  + Use new pygtkspellcheck API (lp#1592727).
  + Fix conversion from old single "Tags" category to new tags
    format.
- Drop appdata.patch: Fixed upstream.
* Sun Sep 25 2016 mailaender@opensuse.org
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Mon Jun 27 2016 zaitor@opensuse.org
- Update to version 1.13:
  + When selecting a journal directory, show all journal
    directories by default.
  + Allow ampersands in e-mail addresses (lp#1570476).
  + python-gtkspell has been renamed to python-gtkspellcheck.
    Update docs and debian/control accordingly.
* Mon Apr 18 2016 ushamim@linux.com
- Update to version 1.12:
  + Add option to hide right-hand tags pane.
  + Never overwrite externally changed month files.
  + Remove support for Python 2.6.
* Thu Dec 31 2015 badshah400@gmail.com
- Update to version 1.11:
  + Remind users to make new backup if last backup is older than
    a month.
  + When inserting a link for a selected text passage, replace
    text passage.
- Changes from version 1.10.4:
  + Fix right-clicking cloud words to hide them.
- Changes from version 1.10.3:
  + Make #hashtags regular expression faster (up to 1000x).
- Update file list: README got renamed to README.md.
* Sun Oct 11 2015 gour@atmarama.net
- Update to version 1.10.2:
  + Fix Chinese fonts in preview mode on Windows by using the fonts
    mingliu and MS Mincho.
  + Fix instructions for running RedNotebook on Windows.
  + Move repository from launchpad to github.
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 1.10.1:
  + When undoing a formatting action, only remove formatting, not
    the text (lp#1326606).
  + Fix searching with enter for text with non-ASCII characters
    (lp#1430697).
  + Fix filtering exports by tags containing non-ASCII characters
    (lp#1267263).
  + Don't remove whitespace from old-style tags in autocomplete box
    (lp#1414603).
  + Don't try to change spellchecking language if spellchecker is
    not set up (lp#1443818).
  + Don't try to access files with wrong encoding (lp#1443818).
* Sun Apr 12 2015 zaitor@opensuse.org
- Update to version 1.10:
  + Write data to temporary files first to prevent corrupted month
    files.
  + Add format button for monospace font. Automatically add the
    correct format for code blocks.
  + Show warning for dates before 1900 (not supported by Python's
    datetime module).
  + Fix undo/redo.
  + Don't add unneeded newlines around titles and code.
* Sun Jan 18 2015 sfalken@opensuse.org
- Update to version 1.9.0:
  + Add #tags to cloud ignore list to remove them from the tag
    cloud (thanks Przemysław Buczkowski).
  + Remove option to start RedNotebook minimized.
  + Do not remove menu bar in fullscreen mode (lp#1400356).
  + Allow exiting fullscreen mode with ESC key.
  + Only allow comment signs (#) at the beginning of a line in the
    config file.
  + Fix reading configuration files.
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 1.8.1:
  + Do not show new version dialog if latest version cannot be
    determined (lp#1324126).
  + Fix date formatting for invalid locale encodings.
  + Add necessary library files for spell-checking on Windows
    (lp#1331876).
* Mon Dec 23 2013 dimstar@opensuse.org
- Update to version 1.8.0:
  + Add font selection for edit mode.
  + Allow changing preview and cloud font in preferences.
  + Only allow opening RedNotebook minimized on Windows since other
    systems may lack a system tray.
  + Fix: Display tags starting with "SEP" in preview (lp#1255582).
  + Write scripts to cross-compile RedNotebook Windows exe and
    installer on Linux.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 1.7.3:
  + Jump to a specific date on startup with "--date 2013-10-31" on
    the commandline.
  + Display current date in the title bar.
  + Support inserting multiple pictures in one step.
  + Add DejaVu Sans as font fallback for clouds and preview.
  + Fix setting last image directory for insert dialog.
  + Only allow exporting selected text if we are in edit mode
    (lp#1221792).
  + Updated translations.
* Sat Jun 29 2013 zaitor@opensuse.org
- Update to version 1.7.2:
  + Show error if saving fails due to a directory not being
    created.
  + Ignore hashtags starting with more than one #.
  + Fix: Allow inserting files and pictures from the "recently
    used" section (lp#1195759).
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 1.7.1:
  + Fix: Insert spellchecking correction in the correct position
    (lp#1137925).
- Changes from version 1.7.0:
  + Allow filtering exported days by tags.
  + Add option to export only the currently selected text.
  + Move spellcheck option from preferences to edit menu and add F7
    shortcut.
  + Enable spellchecking on Windows. See help for adding custom
    dictionaries.
  + Better error message for invalid markup.
  + Show warning if no directory is selected before clicking the
    "Open" button when choosing a journal directory.
  + Gracefully handle BadStatusLines when checking for new
    versions.
  + Do not try to set file permissions on Windows where they are
    unavailable.
  + Fix hide-from-cloud for words containing backslashes
    (lp#1131412).
  + Fix relative file links on Windows.
  + Code: Switch from optparse to argparse.
* Sat Feb  9 2013 zaitor@opensuse.org
- Update to version 1.6.6:
  + Edit templates in RedNotebook directly. Preview and use the
    Insert and Format toolbar menus before inserting a template.
  + Support relative image links like [""my_pic"".jpg].
  + Add Ctrl+Return shortcut for adding manual linebreaks.
  + Let all toolbar menus always open the menu before performing an
    action.
  + Change Go-To-Today shortcut to Alt+Home (Ctrl+Home moves cursor
    to the start of the text).
  + Do not allow choosing an empty name for templates.
  + Do not parse #include as a hashtag.
  + Add info about network drives to help text.
  + Fix help text about links to local directories.
  + Fix: Let categories pane use new infobar notifications
    (lp#1098625).
* Sun Jan  6 2013 dimstar@opensuse.org
- Update to version 1.6.5:
  + Add menu item for clearing the text format.
  + Add toolbar menus "Insert" and "Format" to main menu for better
    accessibility and HUD integration.
  + Only show keyboard shortcuts in main menu, not in toolbar menus
  + Use selected text as link name when a new link is inserted.
  + When an image or file is inserted, use selected text as the
    name of the link.
  + Format selected text as header when a header is inserted.
  + Convert selected text to a list when a list is inserted.
  + Select title after it has been inserted to allow for easy
    editing.
  + Change file permissions so that journal files are only readable
    by the user.
  + Windows: Restore slider positions after opening RedNotebook
    from the tray.
  + Windows: Support non-ascii installation paths.
* Sun Dec 23 2012 zaitor@opensuse.org
- Update to version 1.6.4:
  + Never include previous RedNotebook backups in new backups.
  + Add strikethrough shortcut Ctrl+K.
  + By default don't switch between edit and preview mode
    automatically.
  + Add experimental support for irc protocol.
* Fri Dec  7 2012 dimstar@opensuse.org
- Update to version 1.6.3:
  + Fix: Don't interpret URLs with non-empty paths as local links.
* Mon Nov 19 2012 zaitor@opensuse.org
- Update to version 1.6.2:
  + Add option for automatically switching between edit and preview
    mode to preferences.
  + Since debian doesn't have a python2 symlink, try to run
    python2.7 and python2.6 in the run script.
  + Use PNG image in about dialog (SVG support is broken in Windows
    version).
- Changes from version 1.6.1:
  + Allow specifying the width when inserting an image.
  + Add relative links: Relative paths [myfile image.jpg] is
    automatically transformed to /path/to/journal/image.jpg.
  + Use smarter regular expression for finding hashtags in the text
  + Give focus to link box when the link dialog opens.
  + Hide tag panel by default.
  + Adapt introductory and help texts for hashtags.
  + Break search results at newlines.
  + Fix: When searching for multiple tags, only add a single result
    for every hit.
* Thu Nov  1 2012 dimstar@opensuse.org
- Update to version 1.6.0:
  + Add inline #hashtagging.
  + Allow for automatic switching between edit and preview mode.
  + Many other new features and bugfixes.
* Sun Jul 22 2012 zaitor@opensuse.org
- Update to version 1.5.0:
  + New scalable logo.
  + Remember possible undo/redo actions for each day separately.
  + Turn all entries of old "Tags" categories into tags without
    entries at startup.
  + Suggest last tag when a new tag is added.
  + When suggesting to use the last tag, leave focus on the tag.
  + Enable copy menu item in preview mode. (lp#834473)
  + Only allow hiding words from the cloud, not the tags.
  + Add shortcut (Ctrl+Home) for "Go to Today".
  + Fix undo for tags.
  + Drop support for Python 2.5. This means that we now support
    Python 2.6 and 2.7.
  + Install translation files in standard directories. (lp#687349)
- Added lang package.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 1.4.0:
  + Search:
  - If a search contains a hashtag (e.g. #Work or #Movies), only
    days with all of those tags will be searched. This means you
    can e.g. search for "project-xyz" only in the days tagged
    with "Work" with the query "#Work project-xyz".
  - Search for combinations of tags (e.g. #magazine #linux)
  - If the query only contains a single hashtag (e.g. #Movies), a
    list of all subtags (the names of the movies) is shown.
  - Auto-complete tags in search
  - Automatically scroll to found text in edit mode
  + Split tag and word clouds
  + Show tag and word cloud only if there are any tags and words
    respectively
  + Remove spaces from multi-word tags during search and in clouds
  + Always include all tags regardless of their frequency in the
    cloud
  + Exports:
  - Correctly set the appropriate extension for each export type
  - Always add a title for LaTeX exports
  + Other fixes:
  - Correctly parse configuration values containing ='s
  - Paths returned from file and folder choosers must be
    converted to unicode
  - Correctly redirect error output into the logfile on Windows
* Wed Jan 25 2012 vuntz@opensuse.org
- Update to version 1.3.0:
  + Let tags be categories without entries. This greatly simplifies
    and in fact unifies tags and categories.
  + Unify clouds and search -> Show the search bar above the clouds
    When a search is made, substitute the word cloud with the
    search results.
  + Apply styling for thick horizontal lines
  - Thin line:  --------------------
  - Thick line: ====================
  + Apply formatting only once if a format button is clicked
    multiple times
  + Allow "Close to tray" only on Windows as most modern Linux
    distros don't have a tray anymore (lp#902228). If you still
    want the tray icon, set closeToTray=1 in the configuration
    file.
  + Make journal saving more than twice as fast by using libyaml.
  + Change Ctrl-PageUp(Down) directions to be more intuitive
  + Update and revise help text
  + Fix: utf-8 special chars not displayed correctly in html export
    for firefox (lp#910094)
  + Fix: Do not abort if a wrong regex is entered
  + Fix: Correctly highlight all picture formats in edit mode
  + Fix: When the format button is clicked and a tag is selected,
    format it instead of the editor pane
  + Write month only if changes are actually made (lp#871730)
  + Call categories tags in more places
  + Print PDF export path after export
  + Do not warn if second instance is suspected (too many
    false-positives)
  + Updated translations.
* Thu Oct  6 2011 vuntz@opensuse.org
- Update to version 1.2.0:
  + Let the "Back" and "Forward" button jump over empty days
  + Allow wildcards (*,.,?) in cloud black/white lists ("altr."
    hides altro, altra, etc.)
  + Add "Export currently visible day" option in export assistant
  + By default select the time range from today to today in the
    export wizard (lp#834489)
  + Show warning when second RedNotebook instance is started to
    prevent data loss (lp#771396)
  + Add option to set the date format for exports. An empty field
    removes dates from exports.
  + Remember scrollbar and cursor positions when changing between
    days and edit and preview mode
  + Allow double backslashes (\\) in filenames (e.g. for UNC paths)
  + Use Ubuntu font in editor, preview and cloud if it's available
  + Remember last export and backup locations
  + Show the most recent entries at the top of the search list by
    default
  + Search in annotations as well
  + Use auto-completion for all category entries
  + Mention the name of the day in weekday templates
  + Allow linebreaks (\\) only at the end of lines
  + Do not write empty month files to disk
  + Remove "Delete Entry" button (Use the context menu or the
    delete key instead)
  + Add tooltips for category buttons
  + Always keep categories sorted in search and annotations
    drop-down menus
  + Allow markup for links in categories (--http://mypage.com--)
    (lp#782697)
  + Escape regular expression syntax in searches (*, +, etc.)
  + Use a better icon for Annotate (Edit)
  + Add more markup examples to templates help text
  + Fix: Txt2tags highlighting should not allow spaces between
    format markup and text
  + Fix: Do not use str.capitalize() for fonts in txt2tags.py to
    support turkish locales (lp#841698)
  + Fix on Windows: Correctly open local links with whitespace
    (lp#824420)
  + Let "Get help online" point to RedNotebook's answers section at
    launchpad
  + Various code optimizations.
  + Updated translations.
- Change License tag from GPL-2.0+ to GPL-3.0+ as the code is using
  a LGPL-3.0+ module, effectively changing the GPL-2.0+ code to
  GPL-3.0+.
* Tue Aug  9 2011 dimstar@opensuse.org
- Update to version 1.1.8:
  + Fix: Abort startup if yaml file cannot be read to avoid losing
    data.
  + Updated translations.
* Fri Jul 15 2011 malcolmlewis@opensuse.org
- Update to version 1.1.7:
  + Chinese characters are not correctly rendered in preview
    (lp#731273).
  + Screen position not correctly remembered when opened from
    system tray (lp#804792).
  + Date is not inserted if default encoding can not be
    determined.
  + Use smarter internationalization code from elib.intl.
  + Updated translations.
- Update spec file License field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
* Thu May 12 2011 dimstar@opensuse.org
- Update to version 1.1.6:
  + lp#775269: Fix date encoding
  + Updated translations.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 1.1.5:
  + Remove "RedNotebook" title in exports
  + Make templates translatable
  + Fix: Inserted dates always shows the time 00:00h (lp#744624)
  + Mention "--record installed-files" setup.py's option for
    remembering installed files in README.
* Fri Apr  1 2011 toganm@opensuse.org
- Update to version 1.1.4:
  + Add "phone call" and "personal" templates
  + lp#728466: Application crashes while resetting last position
  + lp#719830: Editing a category entry that contains a \\ removes
    the new line symbol
  + Fix: Introductory text is not translated
  + Fix: Properly convert dates to unicode
  + When a format (bold, etc.) is applied with no text selected,
    add whitespace, not descriptive text
  + Add a tooltip for the edit button
  + Improve introductory and help text
  + Do not refer to annotations as "nodes" but as "entries"
  + Translate the word "Categories" in exports
  + In statistics window use "Selected Day" instead of
    "Current Day"
  + Cleanup GUI glade file
  + Updated translations.
* Tue Mar 15 2011 badshah400@gmail.com
- Update to version 1.1.3:
  + Remember window position from last session
  + Restore window position when returning from tray
  + Let the sub-windows be displayed relative to the main screen
  + After searching change to date with single click instead of
    double-click
  + Add useWebkit flag in configuration file
  + Fix: Special characters inflate cloud black-/whitelist
  + Fix: Insertion of templates (lp#696205)
  + Fix: Do not load backup files accidentally (lp#705260)
  + Fix: Preferences window can't be opened (lp#696186)
  + Code: Make pywebkitgtk an explicit requirement
- Change python-webkitgtk Recommends to Requires, following the
  code changes.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call missing relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
* Mon Dec 27 2010 dimstar@opensuse.org
- Update to version 1.1.2:
  + Add fullscreen mode (F11)
  + Let the preview and edit button have the same size
  + Highlight mixed markups (**__Bold underline__**)
  + Highlight structured headers
  + Highlight ``, "", ''
  + lp#614353: Highlight all found occurences of the searched word
  + lp#622456: Fix: Correctly highlight lists
  + lp#657421: Fix: Do not set maximized to True when sending
    RedNotebook to the tray
  + lp#685609: Fix: Add Ctrl-P shortcut for edit button
  + Fix: Add "\" to the list of ignored chars for word clouds
  + Fix: Escape characters before adding results to the search list
  + Fix: Local links with whitespace in latex
  + Windows-related fixes.
  + Updated documentation.
  + Updated translations.
* Tue Dec  7 2010 vuntz@opensuse.org
- Drop rednotebook-desktop-entry.patch, and instead add the
  additional Category with %%suse_update_desktop_file.
- Use Calendar instead of WordProcessor as additional category.
- Shorten the description.
- Change python-webkitgtk Requires to Recommends, as described in
  README.
- Add python-chardet Recommends.
* Thu Nov 18 2010 badshah400@gmail.com
- Initial build (version) 1.1.1
